.. launcher-menus documentation master file, created by
   sphinx-quickstart on Tue Jan 12 12:55:43 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to launcher-menus' documentation!
=========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

-----------------------------------------

.. mdinclude:: ../README.md

-----------------------------------------


Installation
============

.. mdinclude:: ../INSTALL.md

-----------------------------------------


Usage
=====

.. include:: usage.rst

-----------------------------------------


Configuration
=============

.. include:: configuration.rst

=========================================


launcher-menus
==============
.. automodule:: launcher_menus
   :members:

menu() call
-----------

.. autofunction:: launcher_menus.LauncherMenu.__call__


=========================================

TODO
=====

.. include:: todo.rst
